@@ -25,12 +25,11 @@ class AssetManager:
         if(len(url)!=0):
             self.url = url
          
-        if(self.token_file !=None):
-            if(os.path.exists(self.token_file)):
-                self.token = open(self.token_file, 'r').readlines()[0].strip()
+        if(self.token_file !=None and os.path.exists(self.token_file)):
+            self.token = open(self.token_file, 'r').readlines()[0].strip()
                 
-        if(len(self.token)<10):
-            self.token = None
+            if(len(self.token)<10):
+                self.token = None
             
         if(self.token==None and (len(self.access_key)<5 or self.access_key==None) ):
             raise Exception("Please provide access key for unregistered device")
